betty.sphinx.extension.replacements module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.sphinx.extension.replacements module

Provide a Sphinx plugin to apply string replacements to source code.

betty.sphinx.extension.replacements.render_replacements(app: Sphinx, docname: str, source: MutableSequence[str]) → None

  Handle Sphinx’s source-read event to perform string replacements.

betty.sphinx.extension.replacements.setup(app: Sphinx) → None

  Implement Sphinx’s extension setup.